@@ -36,6 +36,7 @@ from moto.ecr.models import ecr_backends
 from moto.s3.exceptions import MissingBucket, MissingKey
 from moto import settings
 from .exceptions import (
+    ConflictException,
     CrossAccountNotAllowed,
     FunctionUrlConfigNotFound,
     InvalidRoleFormat,
@@ -44,6 +45,7 @@ from .exceptions import (
     UnknownLayerVersionException,
     UnknownFunctionException,
     UnknownAliasException,
+    ValidationException,
 )
 from .utils import (
     make_function_arn,
@@ -195,6 +197,22 @@ def _validate_s3_bucket_and_key(
     return key
 
 
+class ImageConfig:
+    def __init__(self, config: Dict[str, Any]) -> None:
+        self.cmd = config.get("Command", [])
+        self.entry_point = config.get("EntryPoint", [])
+        self.working_directory = config.get("WorkingDirectory", "")
+
+    def response(self) -> Dict[str, Any]:
+        return dict(
+            {
+                "Command": self.cmd,
+                "EntryPoint": self.entry_point,
+                "WorkingDirectory": self.working_directory,
+            }
+        )
+
+
 class Permission(CloudFormationModel):
     def __init__(self, region: str):
         self.region = region
@@ -428,6 +446,10 @@ class LambdaFunction(CloudFormationModel, DockerModel):
         self.reserved_concurrency = spec.get("ReservedConcurrentExecutions", None)
 
         # optional
+        self.ephemeral_storage: str
+        self.code_digest: str
+        self.code_bytes: bytes
+
         self.description = spec.get("Description", "")
         self.memory_size = spec.get("MemorySize", 128)
         self.package_type = spec.get("PackageType", None)
@@ -438,6 +460,13 @@ class LambdaFunction(CloudFormationModel, DockerModel):
         self.signing_job_arn = spec.get("SigningJobArn")
         self.code_signing_config_arn = spec.get("CodeSigningConfigArn")
         self.tracing_config = spec.get("TracingConfig") or {"Mode": "PassThrough"}
+        self.architectures: List[str] = spec.get("Architectures", ["x86_64"])
+        self.image_config: ImageConfig = ImageConfig(spec.get("ImageConfig", {}))
+        _es = spec.get("EphemeralStorage")
+        if _es:
+            self.ephemeral_storage = _es["Size"]
+        else:
+            self.ephemeral_storage = 512
 
         self.logs_group_name = f"/aws/lambda/{self.function_name}"
 
@@ -514,8 +543,6 @@ class LambdaFunction(CloudFormationModel, DockerModel):
 
         self.tags = spec.get("Tags") or dict()
 
-        self._aliases: Dict[str, LambdaAlias] = dict()
-
     def __getstate__(self) -> Dict[str, Any]:
         return {
             k: v
@@ -532,6 +559,41 @@ class LambdaFunction(CloudFormationModel, DockerModel):
             datetime.datetime.utcnow()
         )
 
+    @property
+    def architectures(self) -> List[str]:
+        return self._architectures
+
+    @architectures.setter
+    def architectures(self, architectures: List[str]) -> None:
+        if (
+            len(architectures) > 1
+            or not architectures
+            or architectures[0] not in ("x86_64", "arm64")
+        ):
+            raise ValidationException(
+                str(architectures),
+                "architectures",
+                "Member must satisfy constraint: "
+                "[Member must satisfy enum value set: [x86_64, arm64], Member must not be null]",
+            )
+        self._architectures = architectures
+
+    @property
+    def ephemeral_storage(self) -> int:
+        return self._ephemeral_storage
+
+    @ephemeral_storage.setter
+    def ephemeral_storage(self, ephemeral_storage: int) -> None:
+        if ephemeral_storage > 10240:
+            raise ValidationException(
+                str(ephemeral_storage),
+                "ephemeralStorage.size",
+                "Member must have value less than or equal to 10240",
+            )
+
+        # ephemeral_storage < 512 is handled by botocore 1.30.0
+        self._ephemeral_storage = ephemeral_storage
+
     @property
     def vpc_config(self) -> Dict[str, Any]:  # type: ignore[misc]
         config = self._vpc_config.copy()
@@ -583,7 +645,16 @@ class LambdaFunction(CloudFormationModel, DockerModel):
             "SigningProfileVersionArn": self.signing_profile_version_arn,
             "SigningJobArn": self.signing_job_arn,
             "TracingConfig": self.tracing_config,
+            "Architectures": self.architectures,
+            "EphemeralStorage": {
+                "Size": self.ephemeral_storage,
+            },
+            "SnapStart": {"ApplyOn": "None", "OptimizationStatus": "Off"},
         }
+        if self.package_type == "Image":
+            config["ImageConfigResponse"] = {
+                "ImageConfig": self.image_config.response(),
+            }
         if not on_create:
             # Only return this variable after the first creation
             config["LastUpdateStatus"] = "Successful"
@@ -954,43 +1025,6 @@ class LambdaFunction(CloudFormationModel, DockerModel):
     def delete(self, account_id: str, region: str) -> None:
         lambda_backends[account_id][region].delete_function(self.function_name)
 
-    def delete_alias(self, name: str) -> None:
-        self._aliases.pop(name, None)
-
-    def get_alias(self, name: str) -> LambdaAlias:
-        if name in self._aliases:
-            return self._aliases[name]
-        arn = f"arn:aws:lambda:{self.region}:{self.account_id}:function:{self.function_name}:{name}"
-        raise UnknownAliasException(arn)
-
-    def has_alias(self, alias_name: str) -> bool:
-        try:
-            return self.get_alias(alias_name) is not None
-        except UnknownAliasException:
-            return False
-
-    def put_alias(
-        self, name: str, description: str, function_version: str, routing_config: str
-    ) -> LambdaAlias:
-        alias = LambdaAlias(
-            account_id=self.account_id,
-            region=self.region,
-            name=name,
-            function_name=self.function_name,
-            function_version=function_version,
-            description=description,
-            routing_config=routing_config,
-        )
-        self._aliases[name] = alias
-        return alias
-
-    def update_alias(
-        self, name: str, description: str, function_version: str, routing_config: str
-    ) -> LambdaAlias:
-        alias = self.get_alias(name)
-        alias.update(description, function_version, routing_config)
-        return alias
-
     def create_url_config(self, config: Dict[str, Any]) -> "FunctionUrlConfig":
         self.url_config = FunctionUrlConfig(function=self, config=config)
         return self.url_config  # type: ignore[return-value]
@@ -1205,22 +1239,34 @@ class LambdaStorage(object):
         self.region_name = region_name
         self.account_id = account_id
 
+        # function-arn -> alias -> LambdaAlias
+        self._aliases: Dict[str, Dict[str, LambdaAlias]] = defaultdict(lambda: {})
+
     def _get_latest(self, name: str) -> LambdaFunction:
         return self._functions[name]["latest"]
 
     def _get_version(self, name: str, version: str) -> Optional[LambdaFunction]:
         for config in self._functions[name]["versions"]:
-            if str(config.version) == version or config.has_alias(version):
+            if str(config.version) == version:
                 return config
+
         return None
 
-    def delete_alias(self, name: str, function_name: str) -> None:
+    def _get_function_aliases(self, function_name: str) -> Dict[str, LambdaAlias]:
         fn = self.get_function_by_name_or_arn(function_name)
-        return fn.delete_alias(name)
+        return self._aliases[fn.function_arn]
+
+    def delete_alias(self, name: str, function_name: str) -> None:
+        aliases = self._get_function_aliases(function_name)
+        aliases.pop(name, None)
 
     def get_alias(self, name: str, function_name: str) -> LambdaAlias:
-        fn = self.get_function_by_name_or_arn(function_name)
-        return fn.get_alias(name)
+        aliases = self._get_function_aliases(function_name)
+        if name in aliases:
+            return aliases[name]
+
+        arn = f"arn:aws:lambda:{self.region_name}:{self.account_id}:function:{function_name}:{name}"
+        raise UnknownAliasException(arn)
 
     def put_alias(
         self,
@@ -1230,8 +1276,23 @@ class LambdaStorage(object):
         description: str,
         routing_config: str,
     ) -> LambdaAlias:
-        fn = self.get_function_by_name_or_arn(function_name)
-        return fn.put_alias(name, description, function_version, routing_config)
+        fn = self.get_function_by_name_or_arn(function_name, function_version)
+        aliases = self._get_function_aliases(function_name)
+        if name in aliases:
+            arn = f"arn:aws:lambda:{self.region_name}:{self.account_id}:function:{function_name}:{name}"
+            raise ConflictException(f"Alias already exists: {arn}")
+
+        alias = LambdaAlias(
+            account_id=self.account_id,
+            region=self.region_name,
+            name=name,
+            function_name=fn.function_name,
+            function_version=function_version,
+            description=description,
+            routing_config=routing_config,
+        )
+        aliases[name] = alias
+        return alias
 
     def update_alias(
         self,
@@ -1241,8 +1302,13 @@ class LambdaStorage(object):
         description: str,
         routing_config: str,
     ) -> LambdaAlias:
-        fn = self.get_function_by_name_or_arn(function_name)
-        return fn.update_alias(name, description, function_version, routing_config)
+        alias = self.get_alias(name, function_name)
+
+        # errors if new function version doesn't exist
+        self.get_function_by_name_or_arn(function_name, function_version)
+
+        alias.update(description, function_version, routing_config)
+        return alias
 
     def get_function_by_name(
         self, name: str, qualifier: Optional[str] = None
@@ -1256,7 +1322,17 @@ class LambdaStorage(object):
         if qualifier.lower() == "$latest":
             return self._functions[name]["latest"]
 
-        return self._get_version(name, qualifier)
+        found_version = self._get_version(name, qualifier)
+        if found_version:
+            return found_version
+
+        aliases = self._get_function_aliases(name)
+
+        if qualifier in aliases:
+            alias = aliases[qualifier]
+            return self._get_version(name, alias.function_version)
+
+        return None
 
     def list_versions_by_function(self, name: str) -> Iterable[LambdaFunction]:
         if name not in self._functions:
@@ -1266,6 +1342,10 @@ class LambdaStorage(object):
         latest.function_arn += ":$LATEST"
         return [latest] + self._functions[name]["versions"]
 
+    def list_aliases(self, function_name: str) -> Iterable[LambdaAlias]:
+        aliases = self._get_function_aliases(function_name)
+        return sorted(aliases.values(), key=lambda alias: alias.name)
+
     def get_arn(self, arn: str) -> Optional[LambdaFunction]:
         # Function ARN may contain an alias
         # arn:aws:lambda:region:account_id:function:<fn_name>:<alias_name>
@@ -1375,6 +1455,8 @@ class LambdaStorage(object):
                 ):
                     del self._functions[name]
 
+        self._aliases[function.function_arn] = {}
+
     def all(self) -> Iterable[LambdaFunction]:
         result = []
 
@@ -1706,6 +1788,9 @@ class LambdaBackend(BaseBackend):
     def list_versions_by_function(self, function_name: str) -> Iterable[LambdaFunction]:
         return self._lambdas.list_versions_by_function(function_name)
 
+    def list_aliases(self, function_name: str) -> Iterable[LambdaAlias]:
+        return self._lambdas.list_aliases(function_name)
+
     def get_event_source_mapping(self, uuid: str) -> Optional[EventSourceMapping]:
         return self._event_source_mappings.get(uuid)
 
