@@ -1,25 +1,28 @@
-from moto.core import BaseBackend, BaseModel
-from moto.core.utils import iso_8601_datetime_with_milliseconds, BackendDict
+from moto.core import BaseBackend, BackendDict, BaseModel
+from moto.core.utils import iso_8601_datetime_with_milliseconds
 from moto.moto_api._internal import mock_random
 from datetime import datetime
+from typing import Dict, List, Optional
 from .exceptions import RepositoryDoesNotExistException, RepositoryNameExistsException
 
 
 class CodeCommit(BaseModel):
-    def __init__(self, account_id, region, repository_description, repository_name):
+    def __init__(
+        self,
+        account_id: str,
+        region: str,
+        repository_description: str,
+        repository_name: str,
+    ):
         current_date = iso_8601_datetime_with_milliseconds(datetime.utcnow())
         self.repository_metadata = dict()
         self.repository_metadata["repositoryName"] = repository_name
         self.repository_metadata[
             "cloneUrlSsh"
-        ] = "ssh://git-codecommit.{0}.amazonaws.com/v1/repos/{1}".format(
-            region, repository_name
-        )
+        ] = f"ssh://git-codecommit.{region}.amazonaws.com/v1/repos/{repository_name}"
         self.repository_metadata[
             "cloneUrlHttp"
-        ] = "https://git-codecommit.{0}.amazonaws.com/v1/repos/{1}".format(
-            region, repository_name
-        )
+        ] = f"https://git-codecommit.{region}.amazonaws.com/v1/repos/{repository_name}"
         self.repository_metadata["creationDate"] = current_date
         self.repository_metadata["lastModifiedDate"] = current_date
         self.repository_metadata["repositoryDescription"] = repository_description
@@ -31,18 +34,22 @@ class CodeCommit(BaseModel):
 
 
 class CodeCommitBackend(BaseBackend):
-    def __init__(self, region_name, account_id):
+    def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
-        self.repositories = {}
+        self.repositories: Dict[str, CodeCommit] = {}
 
     @staticmethod
-    def default_vpc_endpoint_service(service_region, zones):
+    def default_vpc_endpoint_service(
+        service_region: str, zones: List[str]
+    ) -> List[Dict[str, str]]:
         """Default VPC endpoint service."""
         return BaseBackend.default_vpc_endpoint_service_factory(
             service_region, zones, "codecommit"
         )
 
-    def create_repository(self, repository_name, repository_description):
+    def create_repository(
+        self, repository_name: str, repository_description: str
+    ) -> Dict[str, str]:
         repository = self.repositories.get(repository_name)
         if repository:
             raise RepositoryNameExistsException(repository_name)
@@ -53,14 +60,14 @@ class CodeCommitBackend(BaseBackend):
 
         return self.repositories[repository_name].repository_metadata
 
-    def get_repository(self, repository_name):
+    def get_repository(self, repository_name: str) -> Dict[str, str]:
         repository = self.repositories.get(repository_name)
         if not repository:
             raise RepositoryDoesNotExistException(repository_name)
 
         return repository.repository_metadata
 
-    def delete_repository(self, repository_name):
+    def delete_repository(self, repository_name: str) -> Optional[str]:
         repository = self.repositories.get(repository_name)
 
         if repository:
