@@ -5,7 +5,8 @@ import os
 import re
 import unittest
 from types import FunctionType
-from typing import Any, Callable, Dict, Optional, Set, TypeVar
+from typing import Any, Callable, Dict, Optional, Set, TypeVar, Union
+from typing import ContextManager
 from unittest.mock import patch
 
 import boto3
@@ -29,7 +30,7 @@ DEFAULT_ACCOUNT_ID = "123456789012"
 CALLABLE_RETURN = TypeVar("CALLABLE_RETURN")
 
 
-class BaseMockAWS:
+class BaseMockAWS(ContextManager["BaseMockAWS"]):
     nested_count = 0
     mocks_active = False
 
@@ -65,10 +66,13 @@ class BaseMockAWS:
             self.reset()  # type: ignore[attr-defined]
 
     def __call__(
-        self, func: Callable[..., Any], reset: bool = True, remove_data: bool = True
-    ) -> Any:
+        self,
+        func: Callable[..., "BaseMockAWS"],
+        reset: bool = True,
+        remove_data: bool = True,
+    ) -> Callable[..., "BaseMockAWS"]:
         if inspect.isclass(func):
-            return self.decorate_class(func)
+            return self.decorate_class(func)  # type: ignore
         return self.decorate_callable(func, reset, remove_data)
 
     def __enter__(self) -> "BaseMockAWS":
@@ -116,9 +120,9 @@ class BaseMockAWS:
             self.disable_patching()  # type: ignore[attr-defined]
 
     def decorate_callable(
-        self, func: Callable[..., CALLABLE_RETURN], reset: bool, remove_data: bool
-    ) -> Callable[..., CALLABLE_RETURN]:
-        def wrapper(*args: Any, **kwargs: Any) -> CALLABLE_RETURN:
+        self, func: Callable[..., "BaseMockAWS"], reset: bool, remove_data: bool
+    ) -> Callable[..., "BaseMockAWS"]:
+        def wrapper(*args: Any, **kwargs: Any) -> "BaseMockAWS":
             self.start(reset=reset)
             try:
                 result = func(*args, **kwargs)
@@ -361,7 +365,6 @@ MockAWS = BotocoreEventMockAWS
 
 
 class ServerModeMockAWS(BaseMockAWS):
-
     RESET_IN_PROGRESS = False
 
     def __init__(self, *args: Any, **kwargs: Any):
@@ -427,7 +430,9 @@ class base_decorator:
     def __init__(self, backends: BackendDict):
         self.backends = backends
 
-    def __call__(self, func: Optional[Callable[..., Any]] = None) -> BaseMockAWS:
+    def __call__(
+        self, func: Optional[Callable[..., Any]] = None
+    ) -> Union[BaseMockAWS, Callable[..., BaseMockAWS]]:
         if settings.TEST_SERVER_MODE:
             mocked_backend: BaseMockAWS = ServerModeMockAWS(self.backends)
         else:
