@@ -3,6 +3,7 @@ import json
 import os
 import re
 import warnings
+from typing import Any, Dict
 
 from moto.core.responses import BaseResponse
 from moto.kms.utils import RESERVED_ALIASES, RESERVED_ALIASE_TARGET_KEY_IDS
@@ -17,24 +18,23 @@ from .exceptions import (
 
 
 class KmsResponse(BaseResponse):
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__(service_name="kms")
 
-    @property
-    def parameters(self):
+    def _get_param(self, param_name: str, if_none: Any = None) -> Any:  # type: ignore
         params = json.loads(self.body)
 
         for key in ("Plaintext", "CiphertextBlob"):
             if key in params:
                 params[key] = base64.b64decode(params[key].encode("utf-8"))
 
-        return params
+        return params.get(param_name, if_none)
 
     @property
     def kms_backend(self) -> KmsBackend:
         return kms_backends[self.current_account][self.region]
 
-    def _display_arn(self, key_id):
+    def _display_arn(self, key_id: str) -> str:
         if key_id.startswith("arn:"):
             return key_id
 
@@ -45,7 +45,7 @@ class KmsResponse(BaseResponse):
 
         return f"arn:aws:kms:{self.region}:{self.current_account}:{id_type}{key_id}"
 
-    def _validate_cmk_id(self, key_id):
+    def _validate_cmk_id(self, key_id: str) -> None:
         """Determine whether a CMK ID exists.
 
         - raw key ID
@@ -69,7 +69,7 @@ class KmsResponse(BaseResponse):
         if cmk_id not in self.kms_backend.keys:
             raise NotFoundException(f"Key '{self._display_arn(key_id)}' does not exist")
 
-    def _validate_alias(self, key_id):
+    def _validate_alias(self, key_id: str) -> None:
         """Determine whether an alias exists.
 
         - alias name
@@ -88,8 +88,8 @@ class KmsResponse(BaseResponse):
         if cmk_id is None:
             raise error
 
-    def _validate_key_id(self, key_id):
-        """Determine whether or not a key ID exists.
+    def _validate_key_id(self, key_id: str) -> None:
+        """Determine whether a key ID exists.
 
         - raw key ID
         - key ARN
@@ -105,77 +105,77 @@ class KmsResponse(BaseResponse):
 
         self._validate_cmk_id(key_id)
 
-    def _validate_key_policy(self, key_id, action):
+    def _validate_key_policy(self, key_id: str, action: str) -> None:
         """
         Validate whether the specified action is allowed, given the key policy
         """
         key = self.kms_backend.describe_key(self.kms_backend.get_key_id(key_id))
         validate_policy(key, action)
 
-    def create_key(self):
+    def create_key(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_CreateKey.html"""
-        policy = self.parameters.get("Policy")
-        key_usage = self.parameters.get("KeyUsage")
-        key_spec = self.parameters.get("KeySpec") or self.parameters.get(
+        policy = self._get_param("Policy")
+        key_usage = self._get_param("KeyUsage")
+        key_spec = self._get_param("KeySpec") or self._get_param(
             "CustomerMasterKeySpec"
         )
-        description = self.parameters.get("Description")
-        tags = self.parameters.get("Tags")
-        multi_region = self.parameters.get("MultiRegion")
+        description = self._get_param("Description")
+        tags = self._get_param("Tags")
+        multi_region = self._get_param("MultiRegion")
 
         key = self.kms_backend.create_key(
             policy, key_usage, key_spec, description, tags, multi_region
         )
         return json.dumps(key.to_dict())
 
-    def replicate_key(self):
-        key_id = self.parameters.get("KeyId")
+    def replicate_key(self) -> None:
+        key_id = self._get_param("KeyId")
         self._validate_key_id(key_id)
-        replica_region = self.parameters.get("ReplicaRegion")
+        replica_region = self._get_param("ReplicaRegion")
         self.kms_backend.replicate_key(key_id, replica_region)
 
-    def update_key_description(self):
+    def update_key_description(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_UpdateKeyDescription.html"""
-        key_id = self.parameters.get("KeyId")
-        description = self.parameters.get("Description")
+        key_id = self._get_param("KeyId")
+        description = self._get_param("Description")
 
         self._validate_cmk_id(key_id)
 
         self.kms_backend.update_key_description(key_id, description)
         return json.dumps(None)
 
-    def tag_resource(self):
+    def tag_resource(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_TagResource.html"""
-        key_id = self.parameters.get("KeyId")
-        tags = self.parameters.get("Tags")
+        key_id = self._get_param("KeyId")
+        tags = self._get_param("Tags")
 
         self._validate_cmk_id(key_id)
 
-        result = self.kms_backend.tag_resource(key_id, tags)
-        return json.dumps(result)
+        self.kms_backend.tag_resource(key_id, tags)
+        return "{}"
 
-    def untag_resource(self):
+    def untag_resource(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_UntagResource.html"""
-        key_id = self.parameters.get("KeyId")
-        tag_names = self.parameters.get("TagKeys")
+        key_id = self._get_param("KeyId")
+        tag_names = self._get_param("TagKeys")
 
         self._validate_cmk_id(key_id)
 
-        result = self.kms_backend.untag_resource(key_id, tag_names)
-        return json.dumps(result)
+        self.kms_backend.untag_resource(key_id, tag_names)
+        return "{}"
 
-    def list_resource_tags(self):
+    def list_resource_tags(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_ListResourceTags.html"""
-        key_id = self.parameters.get("KeyId")
+        key_id = self._get_param("KeyId")
         self._validate_cmk_id(key_id)
 
-        tags = self.kms_backend.list_resource_tags(key_id)
+        tags: Dict[str, Any] = self.kms_backend.list_resource_tags(key_id)
         tags.update({"NextMarker": None, "Truncated": False})
         return json.dumps(tags)
 
-    def describe_key(self):
+    def describe_key(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_DescribeKey.html"""
-        key_id = self.parameters.get("KeyId")
+        key_id = self._get_param("KeyId")
 
         self._validate_key_id(key_id)
         self._validate_key_policy(key_id, "kms:DescribeKey")
@@ -184,7 +184,7 @@ class KmsResponse(BaseResponse):
 
         return json.dumps(key.to_dict())
 
-    def list_keys(self):
+    def list_keys(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_ListKeys.html"""
         keys = self.kms_backend.list_keys()
 
@@ -196,17 +196,17 @@ class KmsResponse(BaseResponse):
             }
         )
 
-    def create_alias(self):
+    def create_alias(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_CreateAlias.html"""
         return self._set_alias()
 
-    def update_alias(self):
+    def update_alias(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_UpdateAlias.html"""
         return self._set_alias(update=True)
 
-    def _set_alias(self, update=False):
-        alias_name = self.parameters["AliasName"]
-        target_key_id = self.parameters["TargetKeyId"]
+    def _set_alias(self, update: bool = False) -> str:
+        alias_name = self._get_param("AliasName")
+        target_key_id = self._get_param("TargetKeyId")
 
         if not alias_name.startswith("alias/"):
             raise ValidationException("Invalid identifier")
@@ -243,9 +243,9 @@ class KmsResponse(BaseResponse):
 
         return json.dumps(None)
 
-    def delete_alias(self):
+    def delete_alias(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_DeleteAlias.html"""
-        alias_name = self.parameters["AliasName"]
+        alias_name = self._get_param("AliasName")
 
         if not alias_name.startswith("alias/"):
             raise ValidationException("Invalid identifier")
@@ -256,10 +256,10 @@ class KmsResponse(BaseResponse):
 
         return json.dumps(None)
 
-    def list_aliases(self):
+    def list_aliases(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_ListAliases.html"""
         region = self.region
-        key_id = self.parameters.get("KeyId")
+        key_id = self._get_param("KeyId")
         if key_id is not None:
             self._validate_key_id(key_id)
             key_id = self.kms_backend.get_key_id(key_id)
@@ -298,13 +298,13 @@ class KmsResponse(BaseResponse):
 
         return json.dumps({"Truncated": False, "Aliases": response_aliases})
 
-    def create_grant(self):
-        key_id = self.parameters.get("KeyId")
-        grantee_principal = self.parameters.get("GranteePrincipal")
-        retiring_principal = self.parameters.get("RetiringPrincipal")
-        operations = self.parameters.get("Operations")
-        name = self.parameters.get("Name")
-        constraints = self.parameters.get("Constraints")
+    def create_grant(self) -> str:
+        key_id = self._get_param("KeyId")
+        grantee_principal = self._get_param("GranteePrincipal")
+        retiring_principal = self._get_param("RetiringPrincipal")
+        operations = self._get_param("Operations")
+        name = self._get_param("Name")
+        constraints = self._get_param("Constraints")
 
         grant_id, grant_token = self.kms_backend.create_grant(
             key_id,
@@ -316,9 +316,9 @@ class KmsResponse(BaseResponse):
         )
         return json.dumps({"GrantId": grant_id, "GrantToken": grant_token})
 
-    def list_grants(self):
-        key_id = self.parameters.get("KeyId")
-        grant_id = self.parameters.get("GrantId")
+    def list_grants(self) -> str:
+        key_id = self._get_param("KeyId")
+        grant_id = self._get_param("GrantId")
 
         grants = self.kms_backend.list_grants(key_id=key_id, grant_id=grant_id)
         return json.dumps(
@@ -329,8 +329,8 @@ class KmsResponse(BaseResponse):
             }
         )
 
-    def list_retirable_grants(self):
-        retiring_principal = self.parameters.get("RetiringPrincipal")
+    def list_retirable_grants(self) -> str:
+        retiring_principal = self._get_param("RetiringPrincipal")
 
         grants = self.kms_backend.list_retirable_grants(retiring_principal)
         return json.dumps(
@@ -341,24 +341,24 @@ class KmsResponse(BaseResponse):
             }
         )
 
-    def revoke_grant(self):
-        key_id = self.parameters.get("KeyId")
-        grant_id = self.parameters.get("GrantId")
+    def revoke_grant(self) -> str:
+        key_id = self._get_param("KeyId")
+        grant_id = self._get_param("GrantId")
 
         self.kms_backend.revoke_grant(key_id, grant_id)
         return "{}"
 
-    def retire_grant(self):
-        key_id = self.parameters.get("KeyId")
-        grant_id = self.parameters.get("GrantId")
-        grant_token = self.parameters.get("GrantToken")
+    def retire_grant(self) -> str:
+        key_id = self._get_param("KeyId")
+        grant_id = self._get_param("GrantId")
+        grant_token = self._get_param("GrantToken")
 
         self.kms_backend.retire_grant(key_id, grant_id, grant_token)
         return "{}"
 
-    def enable_key_rotation(self):
+    def enable_key_rotation(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_EnableKeyRotation.html"""
-        key_id = self.parameters.get("KeyId")
+        key_id = self._get_param("KeyId")
 
         self._validate_cmk_id(key_id)
 
@@ -366,9 +366,9 @@ class KmsResponse(BaseResponse):
 
         return json.dumps(None)
 
-    def disable_key_rotation(self):
+    def disable_key_rotation(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_EnableKeyRotation.html"""
-        key_id = self.parameters.get("KeyId")
+        key_id = self._get_param("KeyId")
 
         self._validate_cmk_id(key_id)
 
@@ -376,9 +376,9 @@ class KmsResponse(BaseResponse):
 
         return json.dumps(None)
 
-    def get_key_rotation_status(self):
+    def get_key_rotation_status(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_GetKeyRotationStatus.html"""
-        key_id = self.parameters.get("KeyId")
+        key_id = self._get_param("KeyId")
 
         self._validate_cmk_id(key_id)
 
@@ -386,11 +386,11 @@ class KmsResponse(BaseResponse):
 
         return json.dumps({"KeyRotationEnabled": rotation_enabled})
 
-    def put_key_policy(self):
+    def put_key_policy(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_PutKeyPolicy.html"""
-        key_id = self.parameters.get("KeyId")
-        policy_name = self.parameters.get("PolicyName")
-        policy = self.parameters.get("Policy")
+        key_id = self._get_param("KeyId")
+        policy_name = self._get_param("PolicyName")
+        policy = self._get_param("Policy")
         _assert_default_policy(policy_name)
 
         self._validate_cmk_id(key_id)
@@ -399,10 +399,10 @@ class KmsResponse(BaseResponse):
 
         return json.dumps(None)
 
-    def get_key_policy(self):
+    def get_key_policy(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_GetKeyPolicy.html"""
-        key_id = self.parameters.get("KeyId")
-        policy_name = self.parameters.get("PolicyName")
+        key_id = self._get_param("KeyId")
+        policy_name = self._get_param("PolicyName")
         _assert_default_policy(policy_name)
 
         self._validate_cmk_id(key_id)
@@ -410,9 +410,9 @@ class KmsResponse(BaseResponse):
         policy = self.kms_backend.get_key_policy(key_id) or "{}"
         return json.dumps({"Policy": policy})
 
-    def list_key_policies(self):
+    def list_key_policies(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_ListKeyPolicies.html"""
-        key_id = self.parameters.get("KeyId")
+        key_id = self._get_param("KeyId")
 
         self._validate_cmk_id(key_id)
 
@@ -420,11 +420,11 @@ class KmsResponse(BaseResponse):
 
         return json.dumps({"Truncated": False, "PolicyNames": ["default"]})
 
-    def encrypt(self):
+    def encrypt(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_Encrypt.html"""
-        key_id = self.parameters.get("KeyId")
-        encryption_context = self.parameters.get("EncryptionContext", {})
-        plaintext = self.parameters.get("Plaintext")
+        key_id = self._get_param("KeyId")
+        encryption_context = self._get_param("EncryptionContext", {})
+        plaintext = self._get_param("Plaintext")
 
         self._validate_key_id(key_id)
 
@@ -438,10 +438,10 @@ class KmsResponse(BaseResponse):
 
         return json.dumps({"CiphertextBlob": ciphertext_blob_response, "KeyId": arn})
 
-    def decrypt(self):
+    def decrypt(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_Decrypt.html"""
-        ciphertext_blob = self.parameters.get("CiphertextBlob")
-        encryption_context = self.parameters.get("EncryptionContext", {})
+        ciphertext_blob = self._get_param("CiphertextBlob")
+        encryption_context = self._get_param("EncryptionContext", {})
 
         plaintext, arn = self.kms_backend.decrypt(
             ciphertext_blob=ciphertext_blob, encryption_context=encryption_context
@@ -451,12 +451,12 @@ class KmsResponse(BaseResponse):
 
         return json.dumps({"Plaintext": plaintext_response, "KeyId": arn})
 
-    def re_encrypt(self):
+    def re_encrypt(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_ReEncrypt.html"""
-        ciphertext_blob = self.parameters.get("CiphertextBlob")
-        source_encryption_context = self.parameters.get("SourceEncryptionContext", {})
-        destination_key_id = self.parameters.get("DestinationKeyId")
-        destination_encryption_context = self.parameters.get(
+        ciphertext_blob = self._get_param("CiphertextBlob")
+        source_encryption_context = self._get_param("SourceEncryptionContext", {})
+        destination_key_id = self._get_param("DestinationKeyId")
+        destination_encryption_context = self._get_param(
             "DestinationEncryptionContext", {}
         )
 
@@ -483,9 +483,9 @@ class KmsResponse(BaseResponse):
             }
         )
 
-    def disable_key(self):
+    def disable_key(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_DisableKey.html"""
-        key_id = self.parameters.get("KeyId")
+        key_id = self._get_param("KeyId")
 
         self._validate_cmk_id(key_id)
 
@@ -493,9 +493,9 @@ class KmsResponse(BaseResponse):
 
         return json.dumps(None)
 
-    def enable_key(self):
+    def enable_key(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_EnableKey.html"""
-        key_id = self.parameters.get("KeyId")
+        key_id = self._get_param("KeyId")
 
         self._validate_cmk_id(key_id)
 
@@ -503,9 +503,9 @@ class KmsResponse(BaseResponse):
 
         return json.dumps(None)
 
-    def cancel_key_deletion(self):
+    def cancel_key_deletion(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_CancelKeyDeletion.html"""
-        key_id = self.parameters.get("KeyId")
+        key_id = self._get_param("KeyId")
 
         self._validate_cmk_id(key_id)
 
@@ -513,13 +513,13 @@ class KmsResponse(BaseResponse):
 
         return json.dumps({"KeyId": key_id})
 
-    def schedule_key_deletion(self):
+    def schedule_key_deletion(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_ScheduleKeyDeletion.html"""
-        key_id = self.parameters.get("KeyId")
-        if self.parameters.get("PendingWindowInDays") is None:
+        key_id = self._get_param("KeyId")
+        if self._get_param("PendingWindowInDays") is None:
             pending_window_in_days = 30
         else:
-            pending_window_in_days = self.parameters.get("PendingWindowInDays")
+            pending_window_in_days = self._get_param("PendingWindowInDays")
 
         self._validate_cmk_id(key_id)
 
@@ -532,12 +532,12 @@ class KmsResponse(BaseResponse):
             }
         )
 
-    def generate_data_key(self):
+    def generate_data_key(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_GenerateDataKey.html"""
-        key_id = self.parameters.get("KeyId")
-        encryption_context = self.parameters.get("EncryptionContext", {})
-        number_of_bytes = self.parameters.get("NumberOfBytes")
-        key_spec = self.parameters.get("KeySpec")
+        key_id = self._get_param("KeyId")
+        encryption_context = self._get_param("EncryptionContext", {})
+        number_of_bytes = self._get_param("NumberOfBytes")
+        key_spec = self._get_param("KeySpec")
 
         # Param validation
         self._validate_key_id(key_id)
@@ -587,16 +587,16 @@ class KmsResponse(BaseResponse):
             }
         )
 
-    def generate_data_key_without_plaintext(self):
+    def generate_data_key_without_plaintext(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_GenerateDataKeyWithoutPlaintext.html"""
         result = json.loads(self.generate_data_key())
         del result["Plaintext"]
 
         return json.dumps(result)
 
-    def generate_random(self):
+    def generate_random(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_GenerateRandom.html"""
-        number_of_bytes = self.parameters.get("NumberOfBytes")
+        number_of_bytes = self._get_param("NumberOfBytes")
 
         if number_of_bytes and (number_of_bytes > 1024 or number_of_bytes < 1):
             raise ValidationException(
@@ -613,13 +613,13 @@ class KmsResponse(BaseResponse):
 
         return json.dumps({"Plaintext": response_entropy})
 
-    def sign(self):
+    def sign(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_Sign.html"""
-        key_id = self.parameters.get("KeyId")
-        message = self.parameters.get("Message")
-        message_type = self.parameters.get("MessageType")
-        grant_tokens = self.parameters.get("GrantTokens")
-        signing_algorithm = self.parameters.get("SigningAlgorithm")
+        key_id = self._get_param("KeyId")
+        message = self._get_param("Message")
+        message_type = self._get_param("MessageType")
+        grant_tokens = self._get_param("GrantTokens")
+        signing_algorithm = self._get_param("SigningAlgorithm")
 
         self._validate_key_id(key_id)
 
@@ -660,14 +660,14 @@ class KmsResponse(BaseResponse):
             }
         )
 
-    def verify(self):
+    def verify(self) -> str:
         """https://docs.aws.amazon.com/kms/latest/APIReference/API_Verify.html"""
-        key_id = self.parameters.get("KeyId")
-        message = self.parameters.get("Message")
-        message_type = self.parameters.get("MessageType")
-        signature = self.parameters.get("Signature")
-        signing_algorithm = self.parameters.get("SigningAlgorithm")
-        grant_tokens = self.parameters.get("GrantTokens")
+        key_id = self._get_param("KeyId")
+        message = self._get_param("Message")
+        message_type = self._get_param("MessageType")
+        signature = self._get_param("Signature")
+        signing_algorithm = self._get_param("SigningAlgorithm")
+        grant_tokens = self._get_param("GrantTokens")
 
         self._validate_key_id(key_id)
 
@@ -721,7 +721,24 @@ class KmsResponse(BaseResponse):
             }
         )
 
+    def get_public_key(self) -> str:
+        key_id = self._get_param("KeyId")
 
-def _assert_default_policy(policy_name):
+        self._validate_key_id(key_id)
+        self._validate_cmk_id(key_id)
+        key, public_key = self.kms_backend.get_public_key(key_id)
+        return json.dumps(
+            {
+                "CustomerMasterKeySpec": key.key_spec,
+                "EncryptionAlgorithms": key.encryption_algorithms,
+                "KeyId": key.id,
+                "KeyUsage": key.key_usage,
+                "PublicKey": base64.b64encode(public_key).decode("UTF-8"),
+                "SigningAlgorithms": key.signing_algorithms,
+            }
+        )
+
+
+def _assert_default_policy(policy_name: str) -> None:
     if policy_name != "default":
         raise NotFoundException("No such policy exists")
