@@ -18,6 +18,34 @@ from .utils import PAGINATION_MODEL, EventMessageFilter
 MAX_RESOURCE_POLICIES_PER_REGION = 10
 
 
+class Destination(BaseModel):
+    def __init__(
+        self,
+        account_id: str,
+        region: str,
+        destination_name: str,
+        role_arn: str,
+        target_arn: str,
+        access_policy: Optional[str] = None,
+    ):
+        self.access_policy = access_policy
+        self.arn = f"arn:aws:logs:{region}:{account_id}:destination:{destination_name}"
+        self.creation_time = int(unix_time_millis())
+        self.destination_name = destination_name
+        self.role_arn = role_arn
+        self.target_arn = target_arn
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "accessPolicy": self.access_policy,
+            "arn": self.arn,
+            "creationTime": self.creation_time,
+            "destinationName": self.destination_name,
+            "roleArn": self.role_arn,
+            "targetArn": self.target_arn,
+        }
+
+
 class LogQuery(BaseModel):
     def __init__(self, query_id: str, start_time: str, end_time: str, query: str):
         self.query_id = query_id
@@ -655,6 +683,7 @@ class LogsBackend(BaseBackend):
         self.filters = MetricFilters()
         self.queries: Dict[str, LogQuery] = dict()
         self.resource_policies: Dict[str, LogResourcePolicy] = dict()
+        self.destinations: Dict[str, Destination] = dict()
 
     @staticmethod
     def default_vpc_endpoint_service(
@@ -706,6 +735,60 @@ class LogsBackend(BaseBackend):
 
         return groups
 
+    def get_destination(self, destination_name: str) -> Destination:
+        for destination in self.destinations:
+            if self.destinations[destination].destination_name == destination_name:
+                return self.destinations[destination]
+        raise ResourceNotFoundException()
+
+    def put_destination(
+        self, destination_name: str, role_arn: str, target_arn: str
+    ) -> Destination:
+        for _, destination in self.destinations.items():
+            if destination.destination_name == destination_name:
+                if role_arn:
+                    destination.role_arn = role_arn
+                if target_arn:
+                    destination.target_arn = target_arn
+                return destination
+        destination = Destination(
+            self.account_id, self.region_name, destination_name, role_arn, target_arn
+        )
+        self.destinations[destination.arn] = destination
+        return destination
+
+    def delete_destination(self, destination_name: str) -> None:
+        destination = self.get_destination(destination_name)
+        self.destinations.pop(destination.arn)
+        return
+
+    def describe_destinations(
+        self, destination_name_prefix: str, limit: int, next_token: Optional[int] = None
+    ) -> Tuple[List[Dict[str, Any]], Optional[int]]:
+        if limit > 50:
+            raise InvalidParameterException(
+                constraint="Member must have value less than or equal to 50",
+                parameter="limit",
+                value=limit,
+            )
+
+        result = []
+        for destination in self.destinations:
+            result.append(self.destinations[destination].to_dict())
+        if next_token:
+            result = result[: int(next_token)]
+        result = [
+            destination
+            for destination in result
+            if destination["destinationName"].startswith(destination_name_prefix)
+        ]
+        return result, next_token
+
+    def put_destination_policy(self, destination_name: str, access_policy: str) -> None:
+        destination = self.get_destination(destination_name)
+        destination.access_policy = access_policy
+        return
+
     def create_log_stream(self, log_group_name: str, log_stream_name: str) -> None:
         if log_group_name not in self.groups:
             raise ResourceNotFoundException()
