@@ -1,12 +1,15 @@
 from collections import OrderedDict
+from typing import Any, Dict, List, Optional
 
 from moto.core import BaseBackend, BackendDict, BaseModel
 from moto.mediaconnect.exceptions import NotFoundException
 from moto.moto_api._internal import mock_random as random
+from moto.utilities.tagging_service import TaggingService
 
 
 class Flow(BaseModel):
-    def __init__(self, **kwargs):
+    def __init__(self, account_id: str, region_name: str, **kwargs: Any):
+        self.id = random.uuid4().hex
         self.availability_zone = kwargs.get("availability_zone")
         self.entitlements = kwargs.get("entitlements", [])
         self.name = kwargs.get("name")
@@ -15,17 +18,19 @@ class Flow(BaseModel):
         self.source_failover_config = kwargs.get("source_failover_config", {})
         self.sources = kwargs.get("sources", [])
         self.vpc_interfaces = kwargs.get("vpc_interfaces", [])
-        self.status = "STANDBY"  # one of 'STANDBY'|'ACTIVE'|'UPDATING'|'DELETING'|'STARTING'|'STOPPING'|'ERROR'
-        self._previous_status = None
-        self.description = None
-        self.flow_arn = None
-        self.egress_ip = None
+        self.status: Optional[
+            str
+        ] = "STANDBY"  # one of 'STANDBY'|'ACTIVE'|'UPDATING'|'DELETING'|'STARTING'|'STOPPING'|'ERROR'
+        self._previous_status: Optional[str] = None
+        self.description = "A Moto test flow"
+        self.flow_arn = f"arn:aws:mediaconnect:{region_name}:{account_id}:flow:{self.id}:{self.name}"
+        self.egress_ip = "127.0.0.1"
         if self.source and not self.sources:
             self.sources = [
                 self.source,
             ]
 
-    def to_dict(self, include=None):
+    def to_dict(self, include: Optional[List[str]] = None) -> Dict[str, Any]:
         data = {
             "availabilityZone": self.availability_zone,
             "description": self.description,
@@ -47,7 +52,7 @@ class Flow(BaseModel):
             return new_data
         return data
 
-    def resolve_transient_states(self):
+    def resolve_transient_states(self) -> None:
         if self.status in ["STARTING"]:
             self.status = "ACTIVE"
         if self.status in ["STOPPING"]:
@@ -57,26 +62,18 @@ class Flow(BaseModel):
             self._previous_status = None
 
 
-class Resource(BaseModel):
-    def __init__(self, **kwargs):
-        self.resource_arn = kwargs.get("resource_arn")
-        self.tags = OrderedDict()
-
-    def to_dict(self):
-        data = {
-            "resourceArn": self.resource_arn,
-            "tags": self.tags,
-        }
-        return data
-
-
 class MediaConnectBackend(BaseBackend):
-    def __init__(self, region_name, account_id):
+    def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
-        self._flows = OrderedDict()
-        self._resources = OrderedDict()
+        self._flows: Dict[str, Flow] = OrderedDict()
+        self.tagger = TaggingService()
 
-    def _add_source_details(self, source, flow_id, ingest_ip="127.0.0.1"):
+    def _add_source_details(
+        self,
+        source: Optional[Dict[str, Any]],
+        flow_id: str,
+        ingest_ip: str = "127.0.0.1",
+    ) -> None:
         if source:
             source["sourceArn"] = (
                 f"arn:aws:mediaconnect:{self.region_name}:{self.account_id}:source"
@@ -85,7 +82,9 @@ class MediaConnectBackend(BaseBackend):
             if not source.get("entitlementArn"):
                 source["ingestIp"] = ingest_ip
 
-    def _add_entitlement_details(self, entitlement, entitlement_id):
+    def _add_entitlement_details(
+        self, entitlement: Optional[Dict[str, Any]], entitlement_id: str
+    ) -> None:
         if entitlement:
             entitlement["entitlementArn"] = (
                 f"arn:aws:mediaconnect:{self.region_name}"
@@ -93,15 +92,9 @@ class MediaConnectBackend(BaseBackend):
                 f":{entitlement['name']}"
             )
 
-    def _create_flow_add_details(self, flow):
-        flow_id = random.uuid4().hex
-
-        flow.description = "A Moto test flow"
-        flow.egress_ip = "127.0.0.1"
-        flow.flow_arn = f"arn:aws:mediaconnect:{self.region_name}:{self.account_id}:flow:{flow_id}:{flow.name}"
-
+    def _create_flow_add_details(self, flow: Flow) -> None:
         for index, _source in enumerate(flow.sources):
-            self._add_source_details(_source, flow_id, f"127.0.0.{index}")
+            self._add_source_details(_source, flow.id, f"127.0.0.{index}")
 
         for index, output in enumerate(flow.outputs or []):
             if output.get("protocol") in ["srt-listener", "zixi-pull"]:
@@ -119,16 +112,18 @@ class MediaConnectBackend(BaseBackend):
 
     def create_flow(
         self,
-        availability_zone,
-        entitlements,
-        name,
-        outputs,
-        source,
-        source_failover_config,
-        sources,
-        vpc_interfaces,
-    ):
+        availability_zone: str,
+        entitlements: List[Dict[str, Any]],
+        name: str,
+        outputs: List[Dict[str, Any]],
+        source: Dict[str, Any],
+        source_failover_config: Dict[str, Any],
+        sources: List[Dict[str, Any]],
+        vpc_interfaces: List[Dict[str, Any]],
+    ) -> Flow:
         flow = Flow(
+            account_id=self.account_id,
+            region_name=self.region_name,
             availability_zone=availability_zone,
             entitlements=entitlements,
             name=name,
@@ -142,11 +137,14 @@ class MediaConnectBackend(BaseBackend):
         self._flows[flow.flow_arn] = flow
         return flow
 
-    def list_flows(self, max_results, next_token):
+    def list_flows(self, max_results: Optional[int]) -> List[Dict[str, Any]]:
+        """
+        Pagination is not yet implemented
+        """
         flows = list(self._flows.values())
         if max_results is not None:
             flows = flows[:max_results]
-        response_flows = [
+        return [
             fl.to_dict(
                 include=[
                     "availabilityZone",
@@ -159,74 +157,59 @@ class MediaConnectBackend(BaseBackend):
             )
             for fl in flows
         ]
-        return response_flows, next_token
 
-    def describe_flow(self, flow_arn=None):
-        messages = {}
+    def describe_flow(self, flow_arn: str) -> Flow:
         if flow_arn in self._flows:
             flow = self._flows[flow_arn]
             flow.resolve_transient_states()
-        else:
-            raise NotFoundException(message="Flow not found.")
-        return flow.to_dict(), messages
+            return flow
+        raise NotFoundException(message="Flow not found.")
 
-    def delete_flow(self, flow_arn):
+    def delete_flow(self, flow_arn: str) -> Flow:
         if flow_arn in self._flows:
-            flow = self._flows[flow_arn]
-            del self._flows[flow_arn]
-        else:
-            raise NotFoundException(message="Flow not found.")
-        return flow_arn, flow.status
+            return self._flows.pop(flow_arn)
+        raise NotFoundException(message="Flow not found.")
 
-    def start_flow(self, flow_arn):
+    def start_flow(self, flow_arn: str) -> Flow:
         if flow_arn in self._flows:
             flow = self._flows[flow_arn]
             flow.status = "STARTING"
-        else:
-            raise NotFoundException(message="Flow not found.")
-        return flow_arn, flow.status
+            return flow
+        raise NotFoundException(message="Flow not found.")
 
-    def stop_flow(self, flow_arn):
+    def stop_flow(self, flow_arn: str) -> Flow:
         if flow_arn in self._flows:
             flow = self._flows[flow_arn]
             flow.status = "STOPPING"
-        else:
-            raise NotFoundException(message="Flow not found.")
-        return flow_arn, flow.status
+            return flow
+        raise NotFoundException(message="Flow not found.")
 
-    def tag_resource(self, resource_arn, tags):
-        if resource_arn in self._resources:
-            resource = self._resources[resource_arn]
-        else:
-            resource = Resource(resource_arn=resource_arn)
-        resource.tags.update(tags)
-        self._resources[resource_arn] = resource
-        return None
+    def tag_resource(self, resource_arn: str, tags: Dict[str, Any]) -> None:
+        tag_list = TaggingService.convert_dict_to_tags_input(tags)
+        self.tagger.tag_resource(resource_arn, tag_list)
 
-    def list_tags_for_resource(self, resource_arn):
-        if resource_arn in self._resources:
-            resource = self._resources[resource_arn]
-        else:
-            raise NotFoundException(message="Resource not found.")
-        return resource.tags
+    def list_tags_for_resource(self, resource_arn: str) -> Dict[str, str]:
+        if self.tagger.has_tags(resource_arn):
+            return self.tagger.get_tag_dict_for_resource(resource_arn)
+        raise NotFoundException(message="Resource not found.")
 
-    def add_flow_vpc_interfaces(self, flow_arn, vpc_interfaces):
+    def add_flow_vpc_interfaces(
+        self, flow_arn: str, vpc_interfaces: List[Dict[str, Any]]
+    ) -> Flow:
         if flow_arn in self._flows:
             flow = self._flows[flow_arn]
             flow.vpc_interfaces = vpc_interfaces
-        else:
-            raise NotFoundException(message=f"flow with arn={flow_arn} not found")
-        return flow_arn, flow.vpc_interfaces
+            return flow
+        raise NotFoundException(message=f"flow with arn={flow_arn} not found")
 
-    def add_flow_outputs(self, flow_arn, outputs):
+    def add_flow_outputs(self, flow_arn: str, outputs: List[Dict[str, Any]]) -> Flow:
         if flow_arn in self._flows:
             flow = self._flows[flow_arn]
             flow.outputs = outputs
-        else:
-            raise NotFoundException(message=f"flow with arn={flow_arn} not found")
-        return flow_arn, flow.outputs
+            return flow
+        raise NotFoundException(message=f"flow with arn={flow_arn} not found")
 
-    def remove_flow_vpc_interface(self, flow_arn, vpc_interface_name):
+    def remove_flow_vpc_interface(self, flow_arn: str, vpc_interface_name: str) -> None:
         if flow_arn in self._flows:
             flow = self._flows[flow_arn]
             flow.vpc_interfaces = [
@@ -236,9 +219,8 @@ class MediaConnectBackend(BaseBackend):
             ]
         else:
             raise NotFoundException(message=f"flow with arn={flow_arn} not found")
-        return flow_arn, vpc_interface_name
 
-    def remove_flow_output(self, flow_arn, output_name):
+    def remove_flow_output(self, flow_arn: str, output_name: str) -> None:
         if flow_arn in self._flows:
             flow = self._flows[flow_arn]
             flow.outputs = [
@@ -248,28 +230,27 @@ class MediaConnectBackend(BaseBackend):
             ]
         else:
             raise NotFoundException(message=f"flow with arn={flow_arn} not found")
-        return flow_arn, output_name
 
     def update_flow_output(
         self,
-        flow_arn,
-        output_arn,
-        cidr_allow_list,
-        description,
-        destination,
-        encryption,
-        max_latency,
-        media_stream_output_configuration,
-        min_latency,
-        port,
-        protocol,
-        remote_id,
-        sender_control_port,
-        sender_ip_address,
-        smoothing_latency,
-        stream_id,
-        vpc_interface_attachment,
-    ):
+        flow_arn: str,
+        output_arn: str,
+        cidr_allow_list: List[str],
+        description: str,
+        destination: str,
+        encryption: Dict[str, str],
+        max_latency: int,
+        media_stream_output_configuration: List[Dict[str, Any]],
+        min_latency: int,
+        port: int,
+        protocol: str,
+        remote_id: str,
+        sender_control_port: int,
+        sender_ip_address: str,
+        smoothing_latency: int,
+        stream_id: str,
+        vpc_interface_attachment: Dict[str, str],
+    ) -> Dict[str, Any]:
         if flow_arn not in self._flows:
             raise NotFoundException(message=f"flow with arn={flow_arn} not found")
         flow = self._flows[flow_arn]
@@ -292,10 +273,12 @@ class MediaConnectBackend(BaseBackend):
                 output["smoothingLatency"] = smoothing_latency
                 output["streamId"] = stream_id
                 output["vpcInterfaceAttachment"] = vpc_interface_attachment
-                return flow_arn, output
+                return output
         raise NotFoundException(message=f"output with arn={output_arn} not found")
 
-    def add_flow_sources(self, flow_arn, sources):
+    def add_flow_sources(
+        self, flow_arn: str, sources: List[Dict[str, Any]]
+    ) -> List[Dict[str, Any]]:
         if flow_arn not in self._flows:
             raise NotFoundException(message=f"flow with arn={flow_arn} not found")
         flow = self._flows[flow_arn]
@@ -305,32 +288,32 @@ class MediaConnectBackend(BaseBackend):
             arn = f"arn:aws:mediaconnect:{self.region_name}:{self.account_id}:source:{source_id}:{name}"
             source["sourceArn"] = arn
         flow.sources = sources
-        return flow_arn, sources
+        return sources
 
     def update_flow_source(
         self,
-        flow_arn,
-        source_arn,
-        decryption,
-        description,
-        entitlement_arn,
-        ingest_port,
-        max_bitrate,
-        max_latency,
-        max_sync_buffer,
-        media_stream_source_configurations,
-        min_latency,
-        protocol,
-        sender_control_port,
-        sender_ip_address,
-        stream_id,
-        vpc_interface_name,
-        whitelist_cidr,
-    ):
+        flow_arn: str,
+        source_arn: str,
+        decryption: str,
+        description: str,
+        entitlement_arn: str,
+        ingest_port: int,
+        max_bitrate: int,
+        max_latency: int,
+        max_sync_buffer: int,
+        media_stream_source_configurations: List[Dict[str, Any]],
+        min_latency: int,
+        protocol: str,
+        sender_control_port: int,
+        sender_ip_address: str,
+        stream_id: str,
+        vpc_interface_name: str,
+        whitelist_cidr: str,
+    ) -> Optional[Dict[str, Any]]:
         if flow_arn not in self._flows:
             raise NotFoundException(message=f"flow with arn={flow_arn} not found")
         flow = self._flows[flow_arn]
-        source = next(
+        source: Optional[Dict[str, Any]] = next(
             iter(
                 [source for source in flow.sources if source["sourceArn"] == source_arn]
             ),
@@ -354,13 +337,13 @@ class MediaConnectBackend(BaseBackend):
             source["streamId"] = stream_id
             source["vpcInterfaceName"] = vpc_interface_name
             source["whitelistCidr"] = whitelist_cidr
-        return flow_arn, source
+        return source
 
     def grant_flow_entitlements(
         self,
-        flow_arn,
-        entitlements,
-    ):
+        flow_arn: str,
+        entitlements: List[Dict[str, Any]],
+    ) -> List[Dict[str, Any]]:
         if flow_arn not in self._flows:
             raise NotFoundException(message=f"flow with arn={flow_arn} not found")
         flow = self._flows[flow_arn]
@@ -371,30 +354,30 @@ class MediaConnectBackend(BaseBackend):
             entitlement["entitlementArn"] = arn
 
         flow.entitlements += entitlements
-        return flow_arn, entitlements
+        return entitlements
 
-    def revoke_flow_entitlement(self, flow_arn, entitlement_arn):
+    def revoke_flow_entitlement(self, flow_arn: str, entitlement_arn: str) -> None:
         if flow_arn not in self._flows:
             raise NotFoundException(message=f"flow with arn={flow_arn} not found")
         flow = self._flows[flow_arn]
         for entitlement in flow.entitlements:
             if entitlement_arn == entitlement["entitlementArn"]:
                 flow.entitlements.remove(entitlement)
-                return flow_arn, entitlement_arn
+                return
         raise NotFoundException(
             message=f"entitlement with arn={entitlement_arn} not found"
         )
 
     def update_flow_entitlement(
         self,
-        flow_arn,
-        entitlement_arn,
-        description,
-        encryption,
-        entitlement_status,
-        name,
-        subscribers,
-    ):
+        flow_arn: str,
+        entitlement_arn: str,
+        description: str,
+        encryption: Dict[str, str],
+        entitlement_status: str,
+        name: str,
+        subscribers: List[str],
+    ) -> Dict[str, Any]:
         if flow_arn not in self._flows:
             raise NotFoundException(message=f"flow with arn={flow_arn} not found")
         flow = self._flows[flow_arn]
@@ -405,12 +388,10 @@ class MediaConnectBackend(BaseBackend):
                 entitlement["entitlementStatus"] = entitlement_status
                 entitlement["name"] = name
                 entitlement["subscribers"] = subscribers
-                return flow_arn, entitlement
+                return entitlement
         raise NotFoundException(
             message=f"entitlement with arn={entitlement_arn} not found"
         )
 
-        # add methods from here
-
 
 mediaconnect_backends = BackendDict(MediaConnectBackend, "mediaconnect")
