@@ -9,8 +9,7 @@ class MarketplaceMeteringResponse(BaseResponse):
     def backend(self) -> MeteringMarketplaceBackend:
         return meteringmarketplace_backends[self.current_account][self.region]
 
-    def batch_meter_usage(self):
-        results = []
+    def batch_meter_usage(self) -> str:
         usage_records = json.loads(self.body)["UsageRecords"]
         product_code = json.loads(self.body)["ProductCode"]
         results = self.backend.batch_meter_usage(product_code, usage_records)
