@@ -3,5 +3,5 @@ from moto.core.exceptions import JsonRESTError
 
 
 class ResourceNotFoundException(JsonRESTError):
-    def __init__(self, msg):
+    def __init__(self, msg: str):
         super().__init__("ResourceNotFoundException", msg)
